==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/PrivateEndpointACLArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.PrivateEndpointACLArgs.builder
import com.pulumi.azurenative.webpubsub.kotlin.enums.WebPubSubRequestType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * ACL for a private endpoint
 * @property allow Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 * @property deny Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 * @property name Name of the private endpoint connection
 */
public data class PrivateEndpointACLArgs(
    public val allow: Output<List<Either<String, WebPubSubRequestType>>>? = null,
    public val deny: Output<List<Either<String, WebPubSubRequestType>>>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.PrivateEndpointACLArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.PrivateEndpointACLArgs =
        com.pulumi.azurenative.webpubsub.inputs.PrivateEndpointACLArgs.builder()
            .allow(
                allow?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .deny(
                deny?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateEndpointACLArgs].
 */
@PulumiTagMarker
public class PrivateEndpointACLArgsBuilder internal constructor() {
    private var allow: Output<List<Either<String, WebPubSubRequestType>>>? = null

    private var deny: Output<List<Either<String, WebPubSubRequestType>>>? = null

    private var name: Output<String>? = null

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("uantqneiapjdlsnu")
    public suspend fun allow(`value`: Output<List<Either<String, WebPubSubRequestType>>>) {
        this.allow = value
    }

    @JvmName("draatyyffhiacjji")
    public suspend fun allow(vararg values: Output<Either<String, WebPubSubRequestType>>) {
        this.allow = Output.all(values.asList())
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("hxltwkxqwhvpyeds")
    public suspend fun allow(values: List<Output<Either<String, WebPubSubRequestType>>>) {
        this.allow = Output.all(values)
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("snsnjtjuywlnfhts")
    public suspend fun deny(`value`: Output<List<Either<String, WebPubSubRequestType>>>) {
        this.deny = value
    }

    @JvmName("veyrpkixclpmgphl")
    public suspend fun deny(vararg values: Output<Either<String, WebPubSubRequestType>>) {
        this.deny = Output.all(values.asList())
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("avakqrivwwrcdynf")
    public suspend fun deny(values: List<Output<Either<String, WebPubSubRequestType>>>) {
        this.deny = Output.all(values)
    }

    /**
     * @param value Name of the private endpoint connection
     */
    @JvmName("cmfsfxhmyomlqbks")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("nwsbfuhyjptgwqte")
    public suspend fun allow(`value`: List<Either<String, WebPubSubRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("jgmqypdiegitwads")
    public suspend fun allow(vararg values: Either<String, WebPubSubRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("mxhangmynjxgpcwx")
    public suspend fun deny(`value`: List<Either<String, WebPubSubRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("frisoxoaquvxuecj")
    public suspend fun deny(vararg values: Either<String, WebPubSubRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    /**
     * @param value Name of the private endpoint connection
     */
    @JvmName("pbnjpwrwynrfjkmd")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): PrivateEndpointACLArgs = PrivateEndpointACLArgs(
        allow = allow,
        deny = deny,
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/PrivateEndpointACLArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.PrivateEndpointACLArgs.builder
import com.pulumi.azurenative.webpubsub.kotlin.enums.WebPubSubRequestType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * ACL for a private endpoint
 * @property allow Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 * @property deny Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 * @property name Name of the private endpoint connection
 */
public data class PrivateEndpointACLArgs(
    public val allow: Output<List<Either<String, WebPubSubRequestType>>>? = null,
    public val deny: Output<List<Either<String, WebPubSubRequestType>>>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.PrivateEndpointACLArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.PrivateEndpointACLArgs =
        com.pulumi.azurenative.webpubsub.inputs.PrivateEndpointACLArgs.builder()
            .allow(
                allow?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .deny(
                deny?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateEndpointACLArgs].
 */
@PulumiTagMarker
public class PrivateEndpointACLArgsBuilder internal constructor() {
    private var allow: Output<List<Either<String, WebPubSubRequestType>>>? = null

    private var deny: Output<List<Either<String, WebPubSubRequestType>>>? = null

    private var name: Output<String>? = null

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("yqdkqyyrvdbwkmqb")
    public suspend fun allow(`value`: Output<List<Either<String, WebPubSubRequestType>>>) {
        this.allow = value
    }

    @JvmName("uhicfyiowjargqxr")
    public suspend fun allow(vararg values: Output<Either<String, WebPubSubRequestType>>) {
        this.allow = Output.all(values.asList())
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("mctgynmwrmygmjvf")
    public suspend fun allow(values: List<Output<Either<String, WebPubSubRequestType>>>) {
        this.allow = Output.all(values)
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("lmxmogdhspbxuwbw")
    public suspend fun deny(`value`: Output<List<Either<String, WebPubSubRequestType>>>) {
        this.deny = value
    }

    @JvmName("eeiuhgguihyibynm")
    public suspend fun deny(vararg values: Output<Either<String, WebPubSubRequestType>>) {
        this.deny = Output.all(values.asList())
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("leatlrodrcbmvnew")
    public suspend fun deny(values: List<Output<Either<String, WebPubSubRequestType>>>) {
        this.deny = Output.all(values)
    }

    /**
     * @param value Name of the private endpoint connection
     */
    @JvmName("qlffjdmckwlgadcf")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("otagsqnjgnffeqdq")
    public suspend fun allow(`value`: List<Either<String, WebPubSubRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("tgpjtobjstrvikdm")
    public suspend fun allow(vararg values: Either<String, WebPubSubRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("teqroenkhrwombij")
    public suspend fun deny(`value`: List<Either<String, WebPubSubRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("jrgkdfiwykyqiqfg")
    public suspend fun deny(vararg values: Either<String, WebPubSubRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    /**
     * @param value Name of the private endpoint connection
     */
    @JvmName("duaovmxbjonllymu")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): PrivateEndpointACLArgs = PrivateEndpointACLArgs(
        allow = allow,
        deny = deny,
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
